Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(156)

Unified Diff: tests/corelib/date_time6_test.dart

Issue 11770004: Rename Date to DateTime. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Address comments and keep Backwards-compatibility class Date. Created 7 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « tests/corelib/date_time5_test.dart ('k') | tests/corelib/date_time7_test.dart » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: tests/corelib/date_time6_test.dart
diff --git a/tests/corelib/date_time6_test.dart b/tests/corelib/date_time6_test.dart
index c4a0b02617b8a32e9af3751583cf30c2181d0c82..0b6418cf2419bdf8dad3aa31acf75b0785ec08d7 100644
--- a/tests/corelib/date_time6_test.dart
+++ b/tests/corelib/date_time6_test.dart
@@ -2,11 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
// Test Date comparison operators.
main() {
- var d = new Date.fromMillisecondsSinceEpoch(0, isUtc: true);
- var d2 = new Date.fromMillisecondsSinceEpoch(1, isUtc: true);
+ var d = new DateTime.fromMillisecondsSinceEpoch(0, isUtc: true);
+ var d2 = new DateTime.fromMillisecondsSinceEpoch(1, isUtc: true);
Expect.isTrue(d < d2);
Expect.isTrue(d <= d2);
Expect.isTrue(d2 > d);
@@ -16,8 +16,8 @@ main() {
Expect.isFalse(d > d2);
Expect.isFalse(d >= d2);
- d = new Date.fromMillisecondsSinceEpoch(-1, isUtc: true);
- d2 = new Date.fromMillisecondsSinceEpoch(0, isUtc: true);
+ d = new DateTime.fromMillisecondsSinceEpoch(-1, isUtc: true);
+ d2 = new DateTime.fromMillisecondsSinceEpoch(0, isUtc: true);
Expect.isTrue(d < d2);
Expect.isTrue(d <= d2);
Expect.isTrue(d2 > d);
@@ -2,11 +2,11 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-// Test Date comparison operators.
+// Test DateTime comparison operators.
main() {
« no previous file with comments | « tests/corelib/date_time5_test.dart ('k') | tests/corelib/date_time7_test.dart » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698